#!/bin/sh python
#
# This is an example of how to use STAR-MP to reconstruct architecture scenarios.
#
# In this example, we reconstruct the scenario of the rhea gene within 9 Drosophila
# species (see Figure 9 in STAR-MP citation).
#

# Make sure tools are installed before running the commands in 
# this tutorial.  This can be done with this command:
cd ..
python setup.py install
cd examples

# or you can run from the source directory by setting these environment 
# variables:
export PATH=$PATH:../bin
export PYTHONPATH=$PYTHONPATH:../python

#=============================================================================
# View the (extant) architecture scenario

# show help information
viewarchscen -h

# Usage: viewarchscen [OPTIONS] <species tree> <archfam file>
# 
# Options:
#   -t, --top
#     display species topology only
#   -e, --events 
#     draw events

# view the (extant) architecture scenario

viewarchscen -t config/flies9.stree flies-fams/01386/01386.fam

#=============================================================================
# Reconstruct gene trees

# show help information
starmp -h

# Usage: starmp [OPTION] <data file>
# 
# Options:
#   -s, --stree <species tree>
#     species tree file in newick format
#   -S, --smap <species map>
#     gene to species map
#   -o, --output <output filename prefix>
#     prefix for all output filenames.  Use '-' to display
#     on stdout
# 
#   Miscellaneous:
#     -T, --treeext <tree extension>
#       extension of (rooted) region trees, one per line
#       (default = '.nt.tree')
# 
#   Information:
#     -V, --verbose <verbosity level>
#       0=quiet, 1=minimal, 2=low, 3=medium, 4=high
#     -l, --log <log file>
#       log filename.  Use '-' to display on stdout.

# run STAR-MP for the rhea family using (reconstructed) region trees
# to reproduce the example in Figure 9 of the paper, also use --seed 1024

starmp \
    -s config/flies9.stree \
    -S config/flies9.smap \
    -T .nt.uniq.trees \
    -o flies-fams/01386/01386 \
    -V 2 --log - \
    flies-fams/01386/01386.fam

#=============================================================================
# View the reconstructed architecture scenario

viewarchscen -t -e config/flies9.stree flies-fams/01386/01386.mp

#=============================================================================
# Clean up
#
# Remove all outputs from example analysis
#

find flies-fams/ -type f | egrep -v '\.fam$|\.nt.uniq.trees$' | xargs rm

